#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ONEPLUS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ONEPLUS_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/oneplus.hpp>

#endif
